==> lnl-2.1.8.tar.gz: lnl-2.1.8/src/draw.h <==
#ifndef	__DRAW_H__
#define	__DRAW_H__

#include	<stdio.h>

#include	"menu.h"

#define	OUT_FP	stdout

#define	SCREEN_WIDTH	80
#define	SCREEN_HEIGHT	24
#define	SCREEN_MIN_X	0
#define	SCREEN_MIN_Y	0
#define	SCREEN_MAX_X	(SCREEN_WIDTH - 1)
#define	SCREEN_MAX_Y	(SCREEN_HEIGHT - 1)

/* vfx begin */

#define	VFX_ARW_MAX_N	32
#define	ANIM_FRAME	60.0

#define	ANIM_LINE_LEN	32

#define	ANIM_ARW_FRAME_N	\
		((ANIM_FRAME * 10 / 10) - ANIM_ARW_CLR_FRAME_N)
#define	ANIM_ARW_CLR_FRAME_N	(ANIM_FRAME * 5 / 10)

#define	ANIM_CRTCL_FRAME_N	\
		((ANIM_FRAME * 4 / 10) - ANIM_CRTCL_CLR_FRAME_N)
#define	ANIM_CRTCL_CLR_FRAME_N	(ANIM_FRAME * 2 / 10)
#define	ANIM_CRTCL_R	2
#define	ANIM_CRTCL_WAIT_CLOCK	(ANIM_FRAME * 4 / 10)
#define	STR_ANIM_CRTCL_1	"/"
#define	STR_ANIM_CRTCL_2	"\\"

#define	ANIM_NUM_FRAME_N	(ANIM_FRAME * 10 /10)

#define	ANIM_SPELL_LEN	8
#define	ANIM_SPELL_FRAME_N	\
		((ANIM_FRAME * 10 / 10) - ANIM_ARW_CLR_FRAME_N)
#define	ANIM_SPELL_CLR_FRAME_N	(ANIM_FRAME * 5 / 10)
#define	STR_ANIM_SPELL	"*"

/* vfx end */

#define	WIN_MAP_DRAW_MIN_X	0
#define	WIN_MAP_DRAW_MIN_Y	0
#define	WIN_MAP_DRAW_WIDTH	(WIN_MAP_WIDTH * 2)
#define	WIN_MAP_DRAW_HEIGHT	WIN_MAP_HEIGHT
#define	WIN_MAP_DRAW_MAX_X	(WIN_MAP_DRAW_MIN_X + WIN_MAP_DRAW_WIDTH - 1)
#define	WIN_MAP_DRAW_MAX_Y	(WIN_MAP_DRAW_MIN_Y + WIN_MAP_DRAW_HEIGHT - 1)

#define	WIN_MENU_DRAW_MIN_X	SCREEN_MIN_X
#define	WIN_MENU_DRAW_MIN_Y	SCREEN_MIN_Y
#define	WIN_MENU_DRAW_WIDTH	(WIN_MENU_DRAW_MAX_X - WIN_MENU_DRAW_MIN_X)
#define	WIN_MENU_DRAW_HEIGHT	(WIN_MENU_DRAW_MAX_Y - WIN_MENU_DRAW_MIN_Y)
#define	WIN_MENU_DRAW_MAX_X	SCREEN_MAX_X
#define	WIN_MENU_DRAW_MAX_Y	(WIN_MSG_DRAW_MIN_Y - 1)

#define	WIN_MSG_DRAW_MIN_X	0
#define	WIN_MSG_DRAW_MIN_Y	(WIN_MAP_DRAW_MAX_Y + 2)
#define	WIN_MSG_DRAW_WIDTH	SCREEN_WIDTH
#define	WIN_MSG_DRAW_HEIGHT	1
#define	WIN_MSG_DRAW_MAX_X	(WIN_MSG_DRAW_MIN_X + WIN_MSG_DRAW_WIDTH - 1)
#define	WIN_MSG_DRAW_MAX_Y	(WIN_MSG_DRAW_MIN_Y + WIN_MSG_DRAW_HEIGHT - 1)

#define	WIN_MORE_DRAW_MIN_X	(WIN_MSG_DRAW_MAX_X - WIN_MORE_DRAW_WIDTH + 1)
#define	WIN_MORE_DRAW_MIN_Y	WIN_MSG_DRAW_MIN_Y
#define	WIN_MORE_DRAW_WIDTH	(str_len_draw( MSG_MORE ))

/**/

#define	WIN_STAT_DRAW_MIN_X	(WIN_MAP_DRAW_MAX_X + 1 + 1)
#define	WIN_STAT_DRAW_MIN_Y	0
#define	WIN_STAT_DRAW_HEIGHT	3
#define	WIN_STAT_DRAW_MAX_X	(SCREEN_WIDTH - 1)
#define	WIN_STAT_DRAW_MAX_Y	(WIN_STAT_DRAW_MIN_Y \
		+ ((MBR_MAX_N) * WIN_STAT_DRAW_HEIGHT - 1) - 1)

#define	FLG_MSG_ERR	(1 << 0)
#define	FLG_MSG_MORE	(1 << 1)
#define	FLG_MSG_NO_MORE_PREV	(1 << 2)
#define	FLG_MSG_NO_MORE_NEXT	(1 << 3)

typedef unsigned long	flg_msg_t;

#define	WIN_MAP_WIDTH	20
#define	WIN_MAP_HEIGHT	20

#define	LS_MSG_DRAW_N	20
#define	LS_MSG_MAX_N	(LS_MSG_DRAW_N * 8)

#define	ANIM_FRAME_N	((long)(1.0 * 60.0))

typedef unsigned long	flg_print_t;

#define	VFX_WAIT_MIN_N	1
#define	VFX_WAIT_MAX_N	200
#define	FLG_VFX_MBR_HP_ADD	(1 << 0)
#define	FLG_VFX_MBR_HP_SUB	(1 << 1)
#define	FLG_VFX_MBR_HP_SUB_CRTCL	(1 << 2)
#define	FLG_VFX_MBR_ARW	(1 << 3)
#define	FLG_VFX_MNSTR_HP_ADD	(1 << 0)
#define	FLG_VFX_MNSTR_HP_SUB	(1 << 1)
#define	FLG_VFX_MNSTR_HP_SUB_CRTCL	(1 << 2)
#define	FLG_VFX_MNSTR_ARW	(1 << 3)
typedef unsigned long	flg_vfx_mbr_t;
typedef unsigned long	flg_vfx_mnstr_t;

typedef enum {
	DATA_N_NULL,

	DATA_N_NAME,
	DATA_N_FACE,
	DATA_N_RACE_STR,
	DATA_N_RACE_NAME,
	DATA_N_SEX,

	DATA_N_HP_VAL,
	DATA_N_MP_VAL,

	DATA_N_VAL_TTL,
	DATA_N_HIT,
	DATA_N_WPN_CRTCL,
	DATA_N_DAM,
	DATA_N_DEF,
	DATA_N_ARMOR_CRTCL,
	DATA_N_AC,
	DATA_N_GOLD,
	DATA_N_TURN,

	DATA_N_STAT_TTL,
	DATA_N_STAT_DEAD,
	DATA_N_STAT_STONE,
	DATA_N_STAT_PARALYZE,
	DATA_N_STAT_POISON,
	DATA_N_STAT_CONFUSION,
	DATA_N_STAT_BLIND,
	DATA_N_STAT_SLEEP,
	DATA_N_STAT_SILENCE,
	DATA_N_STAT_FEAR,
	DATA_N_STAT_HALLUCINATION,
	DATA_N_STAT_CHARM,
	DATA_N_STAT_FLY,
	DATA_N_STAT_HUNGRY,
	DATA_N_STAT_FAINT,
	DATA_N_STAT_DRUNK,

	DATA_N_LEV_LEFT,
	DATA_N_EXP_LEFT,
	DATA_N_NEED_EXP_LEFT,
	DATA_N_LEV_RIGHT,
	DATA_N_EXP_RIGHT,
	DATA_N_NEED_EXP_RIGHT,

	DATA_N_HP,
	DATA_N_MP,
	DATA_N_DEX,
	DATA_N_STR,
	DATA_N_AGI,
	DATA_N_WIS,
	DATA_N_INT,
	DATA_N_CHA,

	DATA_N_RESI_TTL,
	DATA_N_RESI_KNOC,
	DATA_N_RESI_SLAS,
	DATA_N_RESI_STIN,
	DATA_N_RESI_HEAT,
	DATA_N_RESI_COLD,
	DATA_N_RESI_WIND,
	DATA_N_RESI_ACID,
	DATA_N_RESI_ELEC,
	DATA_N_RESI_POIS,

	DATA_N_FIG,
	DATA_N_MON,
	DATA_N_HUN,
	DATA_N_THI,
	DATA_N_MAG,
	DATA_N_SOR,
	DATA_N_ENC,
	DATA_N_SUM,
	DATA_N_PRI,
	DATA_N_SHA,
	DATA_N_BAR,
	DATA_N_NIN,

	DATA_N_CLASS,

	DATA_N_NEXT_PAGE,

	DATA_N_MAX_N,
} data_n_t;

typedef enum {
	EDIT_CLASS_NULL,

	EDIT_CLASS_HP,
	EDIT_CLASS_MP,
	EDIT_CLASS_DEX,
	EDIT_CLASS_STR,
	EDIT_CLASS_AGI,
	EDIT_CLASS_WIS,
	EDIT_CLASS_INT,
	EDIT_CLASS_CHA,

	EDIT_CLASS_TOTAL,

	EDIT_CLASS_FIG,
	EDIT_CLASS_MON,
	EDIT_CLASS_HUN,
	EDIT_CLASS_THI,
	EDIT_CLASS_MAG,
	EDIT_CLASS_SOR,
	EDIT_CLASS_ENC,
	EDIT_CLASS_SUM,
	EDIT_CLASS_PRI,
	EDIT_CLASS_SHA,
	EDIT_CLASS_BAR,
	EDIT_CLASS_NIN,

	EDIT_CLASS_NAME,

	EDIT_CLASS_PREV,
	EDIT_CLASS_NEXT,

	EDIT_CLASS_MAX_N,
} edit_class_t;

#endif	/* __DRAW_H__ */

==> lnl-2.1.20.tar.gz: lnl-2.1.20/src/draw.h <==
/*****************************************************************
* L&L - Labyrinths & Legends
* Copyright (c) 1993-2003 YOSHIMURA Tomohiko All rights reserved.
* 
* Created by BowKenKen
*   e-mail: bowkenken@users.sourceforge.jp
*   URL: https://sourceforge.jp/projects/lnl/
* 
* License is GPL
* 
* ܥץϥե꡼եȥǤ
* ʤϡ Free Software Foundation ɽ
*  GNU ̸ͭѵΡ֥С󣲡
* ϤʹߤγƥС椫餤줫򤷡
* ΥС˽äܥץ
* ۤޤѹ뤳ȤǤޤ
* 
* ܥץͭѤȤϻפޤۤˤäƤϡ
* ԾڤŪŬˤĤƤΰۤݾڤޤ,
* ʤݾڤԤʤޤ
* ܺ٤ˤĤƤ GNU ̸ͭѵɤߤ
* 
* ʤϡܥץȰ GNU ̸ͭѵ
* μ̤äƤϤǤǤʤϡ
*   Free Software Foundation, Inc.,
*   59 Temple Place, Suite 330, Boston, MA 02111-1307, USA
* ؼ񤤤Ƥ
* 
* $Id: draw.h,v 1.13 2003/11/19 13:19:13 bowkenken Exp $
*****************************************************************/

#ifndef	DRAW_H
#define	DRAW_H

#include	<stdio.h>

#include	"pet.h"
#include	"menu.h"

#define	OUT_FP	stdout

#define	SCREEN_WIDTH	80
#define	SCREEN_HEIGHT	24
#define	SCREEN_MIN_X	0
#define	SCREEN_MIN_Y	0
#define	SCREEN_MAX_X	(SCREEN_WIDTH - 1)
#define	SCREEN_MAX_Y	(SCREEN_HEIGHT - 1)

/* vfx begin */

#define	VFX_ARW_MAX_N	32
#define	ANIM_FRAME	60

#define	ANIM_LINE_LEN	32

#define	ANIM_ARW_FRAME_N	\
		((ANIM_FRAME * 10 / 10) - ANIM_ARW_CLR_FRAME_N)
#define	ANIM_ARW_CLR_FRAME_N	(ANIM_FRAME * 5 / 10)

#define	ANIM_CRTCL_FRAME_N	\
		((ANIM_FRAME * 4 / 10) - ANIM_CRTCL_CLR_FRAME_N)
#define	ANIM_CRTCL_CLR_FRAME_N	(ANIM_FRAME * 2 / 10)
#define	ANIM_CRTCL_R	2
#define	ANIM_CRTCL_WAIT_CLOCK	(ANIM_FRAME * 4 / 10)
#define	STR_ANIM_CRTCL_1	"/"
#define	STR_ANIM_CRTCL_2	"\\"

#define	ANIM_NUM_FRAME_N	(ANIM_FRAME * 10 / 10)

#define	ANIM_SPELL_LEN	8
#define	ANIM_SPELL_FRAME_N	\
		((ANIM_FRAME * 10 / 10) - ANIM_ARW_CLR_FRAME_N)
#define	ANIM_SPELL_CLR_FRAME_N	(ANIM_FRAME * 5 / 10)

/* vfx end */

#define	WIN_MAP_DRAW_MIN_X	0
#define	WIN_MAP_DRAW_MIN_Y	0
#define	WIN_MAP_DRAW_WIDTH	(WIN_MAP_WIDTH * 2)
#define	WIN_MAP_DRAW_HEIGHT	WIN_MAP_HEIGHT
#define	WIN_MAP_DRAW_MAX_X	(WIN_MAP_DRAW_MIN_X + WIN_MAP_DRAW_WIDTH - 1)
#define	WIN_MAP_DRAW_MAX_Y	(WIN_MAP_DRAW_MIN_Y + WIN_MAP_DRAW_HEIGHT - 1)

#define	WIN_MENU_DRAW_MIN_X	SCREEN_MIN_X
#define	WIN_MENU_DRAW_MIN_Y	SCREEN_MIN_Y
#define	WIN_MENU_DRAW_WIDTH	(WIN_MENU_DRAW_MAX_X - WIN_MENU_DRAW_MIN_X)
#define	WIN_MENU_DRAW_HEIGHT	(WIN_MENU_DRAW_MAX_Y - WIN_MENU_DRAW_MIN_Y)
#define	WIN_MENU_DRAW_MAX_X	SCREEN_MAX_X
#define	WIN_MENU_DRAW_MAX_Y	(WIN_MSG_DRAW_MIN_Y - 1)

#define	WIN_MSG_DRAW_MIN_X	0
#define	WIN_MSG_DRAW_MIN_Y	(WIN_MAP_DRAW_MAX_Y + 2)
#define	WIN_MSG_DRAW_WIDTH	SCREEN_WIDTH
#define	WIN_MSG_DRAW_HEIGHT	1
#define	WIN_MSG_DRAW_MAX_X	(WIN_MSG_DRAW_MIN_X + WIN_MSG_DRAW_WIDTH - 1)
#define	WIN_MSG_DRAW_MAX_Y	(WIN_MSG_DRAW_MIN_Y + WIN_MSG_DRAW_HEIGHT - 1)

#define	WIN_MORE_DRAW_MIN_X	(WIN_MSG_DRAW_MAX_X - WIN_MORE_DRAW_WIDTH + 1)
#define	WIN_MORE_DRAW_MIN_Y	WIN_MSG_DRAW_MIN_Y
#define	WIN_MORE_DRAW_WIDTH	(str_len_draw( MSG_MORE ))

/**/

#define	WIN_STAT_DRAW_MIN_X	(WIN_MAP_DRAW_MAX_X + 1 + 1)
#define	WIN_STAT_DRAW_MIN_Y	0
#define	WIN_STAT_DRAW_WIDTH	\
		(WIN_STAT_DRAW_MAX_X - WIN_STAT_DRAW_MIN_X + 1)
#define	WIN_STAT_DRAW_HEIGHT	3
#define	WIN_STAT_DRAW_MAX_X	(SCREEN_WIDTH - 1)
#define	WIN_STAT_DRAW_MAX_Y	(WIN_STAT_DRAW_MIN_Y \
		+ ((MBR_MAX_N) * WIN_STAT_DRAW_HEIGHT - 1) - 1)

#define	FLG_MSG_ERR	(1 << 0)
#define	FLG_MSG_MORE	(1 << 1)
#define	FLG_MSG_NO_MORE_PREV	(1 << 2)
#define	FLG_MSG_NO_MORE_NEXT	(1 << 3)

typedef unsigned long	flg_msg_t;

#define	WIN_MAP_WIDTH	20
#define	WIN_MAP_HEIGHT	20

#define	LS_MSG_DRAW_N	20
#define	LS_MSG_MAX_N	(LS_MSG_DRAW_N * 8)

#define	ANIM_FRAME_N	((long)(1.0 * 60.0))

typedef unsigned long	flg_print_t;

#define	VFX_WAIT_MIN_N	1
#define	VFX_WAIT_MAX_N	200
#define	FLG_VFX_MBR_HP_ADD	(1 << 0)
#define	FLG_VFX_MBR_HP_SUB	(1 << 1)
#define	FLG_VFX_MBR_HP_SUB_CRTCL	(1 << 2)
#define	FLG_VFX_MBR_ARW	(1 << 3)
#define	FLG_VFX_MNSTR_HP_ADD	(1 << 0)
#define	FLG_VFX_MNSTR_HP_SUB	(1 << 1)
#define	FLG_VFX_MNSTR_HP_SUB_CRTCL	(1 << 2)
#define	FLG_VFX_MNSTR_ARW	(1 << 3)
typedef unsigned long	flg_vfx_mbr_t;
typedef unsigned long	flg_vfx_mnstr_t;

typedef enum {
	DATA_N_NULL,

	DATA_N_NAME,
	DATA_N_FACE,
	DATA_N_RACE_STR,
	DATA_N_RACE_NAME,
	DATA_N_SEX,

	DATA_N_HP_VAL,
	DATA_N_MP_VAL,

	DATA_N_VAL_TTL,
	DATA_N_HIT,
	DATA_N_WPN_CRTCL,
	DATA_N_DAM,
	DATA_N_DEF,
	DATA_N_ARMOR_CRTCL,
	DATA_N_AC,
	DATA_N_GOLD,
	DATA_N_TURN,

	DATA_N_STAT_TTL,
	DATA_N_STAT_DEAD,
	DATA_N_STAT_STONE,
	DATA_N_STAT_PARALYZE,
	DATA_N_STAT_POISON,
	DATA_N_STAT_CONFUSION,
	DATA_N_STAT_BLIND,
	DATA_N_STAT_SLEEP,
	DATA_N_STAT_SILENCE,
	DATA_N_STAT_CAUGHT,
	DATA_N_STAT_FEAR,
	DATA_N_STAT_HALLUCINATION,
	DATA_N_STAT_CHARM,
	DATA_N_STAT_FLY,
	DATA_N_STAT_HUNGRY,
	DATA_N_STAT_FAINT,
	DATA_N_STAT_DRUNK,

	DATA_N_LEV_LEFT,
	DATA_N_EXP_LEFT,
	DATA_N_NEED_EXP_LEFT,
	DATA_N_LEV_RIGHT,
	DATA_N_EXP_RIGHT,
	DATA_N_NEED_EXP_RIGHT,

	DATA_N_HP,
	DATA_N_MP,
	DATA_N_DEX,
	DATA_N_STR,
	DATA_N_AGI,
	DATA_N_WIS,
	DATA_N_INT,
	DATA_N_CHA,

	DATA_N_RESI_TTL,
	DATA_N_RESI_TTL_LAWFUL,
	DATA_N_RESI_TTL_NEUTRAL_1,
	DATA_N_RESI_TTL_CHAOTIC,
	DATA_N_RESI_TTL_GOOD,
	DATA_N_RESI_TTL_NEUTRAL_2,
	DATA_N_RESI_TTL_EVIL,
	DATA_N_RESI_KNOC,
	DATA_N_RESI_SLAS,
	DATA_N_RESI_STIN,
	DATA_N_RESI_HEAT,
	DATA_N_RESI_COLD,
	DATA_N_RESI_ACID,
	DATA_N_RESI_MIND,
	DATA_N_RESI_ELEC,
	DATA_N_RESI_POIS,

	DATA_N_FIG,
	DATA_N_MON,
	DATA_N_HUN,
	DATA_N_THI,
	DATA_N_MAG,
	DATA_N_SOR,
	DATA_N_ENC,
	DATA_N_SUM,
	DATA_N_PRI,
	DATA_N_SHA,
	DATA_N_BAR,
	DATA_N_NIN,

	DATA_N_CLASS,

	DATA_N_NEXT_PAGE,

	DATA_N_MAX_N,
} data_n_t;

typedef enum {
	EDIT_CLASS_NULL,

	EDIT_CLASS_HP,
	EDIT_CLASS_MP,
	EDIT_CLASS_DEX,
	EDIT_CLASS_STR,
	EDIT_CLASS_AGI,
	EDIT_CLASS_WIS,
	EDIT_CLASS_INT,
	EDIT_CLASS_CHA,

	EDIT_CLASS_TOTAL,

	EDIT_CLASS_FIG,
	EDIT_CLASS_MON,
	EDIT_CLASS_HUN,
	EDIT_CLASS_THI,
	EDIT_CLASS_MAG,
	EDIT_CLASS_SOR,
	EDIT_CLASS_ENC,
	EDIT_CLASS_SUM,
	EDIT_CLASS_PRI,
	EDIT_CLASS_SHA,
	EDIT_CLASS_BAR,
	EDIT_CLASS_NIN,

	EDIT_CLASS_NAME,

	EDIT_CLASS_PREV,
	EDIT_CLASS_NEXT,

	EDIT_CLASS_MAX_N,
} edit_class_t;

#endif	/* DRAW_H */
